@@ -33,8 +33,9 @@ THE SOFTWARE.
 #include <time.h>
 #include <sys/types.h>
 #include <sys/socket.h>
-#include <arpa/inet.h>
+#include <sys/uio.h>
 #include <netinet/in.h>
+#include <arpa/inet.h>
 #include <net/if.h>
 
 #include "ahcpd.h"
@@ -315,7 +316,7 @@ main(int argc, char **argv)
     rc = random_eui64(myid);
     if(rc < 0) {
         fprintf(stderr, "Couldn't generate unique id.\n");
-        exit(1);
+        goto fail;
     }
 
  write_unique_id:
@@ -831,7 +832,7 @@ main(int argc, char **argv)
             "              "
             "[-i file] [-s script] [-D] [-I pidfile] [-L logfile]\n"
             "              "
-            "[-c statement] [-C filename]"
+            "[-C statement] [-c filename]"
             "interface...\n");
     exit(1);
 
@@ -973,10 +974,6 @@ ahcp_socket(int port)
     if(s < 0)
         return -1;
 
-    rc = setsockopt(s, IPPROTO_IPV6, IPV6_V6ONLY, &zero, sizeof(one));
-    if(rc < 0)
-        goto fail;
-
     rc = setsockopt(s, SOL_SOCKET, SO_REUSEADDR, &one, sizeof(one));
     if(rc < 0)
         perror("setsockopt(SO_REUSEADDR)");
@@ -1113,7 +1110,7 @@ void
 timeval_minus(struct timeval *d,
               const struct timeval *s1, const struct timeval *s2)
 {
-    if(s1->tv_usec > s2->tv_usec) {
+    if(s1->tv_usec >= s2->tv_usec) {
         d->tv_usec = s1->tv_usec - s2->tv_usec;
         d->tv_sec = s1->tv_sec - s2->tv_sec;
     } else {
