@@ -31,12 +31,13 @@ THE SOFTWARE.
 #include <sys/uio.h>
 #include <fcntl.h>
 #include <sys/wait.h>
-#include <arpa/inet.h>
 #include <sys/time.h>
+#include <sys/socket.h>
 #include <time.h>
 #include <net/if.h>
-#include <sys/ioctl.h>
 #include <netinet/in.h>
+#include <arpa/inet.h>
+#include <sys/ioctl.h>
 
 #ifdef __linux__
 #include <netinet/ether.h>
@@ -505,7 +506,7 @@ parse_message(int configure, const unsigned char *data, int len,
         if(config->ipv6_address) {
             config->our_ipv6_address = copy_prefix_list(config->ipv6_address);
         } else if(config->ipv6_prefix && config->ipv6_prefix->n > 0 &&
-                  config->ipv6_prefix->l[0].plen >= 64) {
+                  config->ipv6_prefix->l[0].plen <= 64) {
             unsigned char address[16];
             int have_address = 0;
 
@@ -863,12 +864,15 @@ int
 random_eui64(unsigned char *eui)
 {
     int fd, rc;
-    fd = open("/dev/random", O_RDONLY);
+
+    /* If there's no /dev/urandom, this will fail with ENOENT,
+       which the caller will deal with gracefully. */
+    fd = open("/dev/urandom", O_RDONLY);
     if(fd < 0)
         return -1;
 
     rc = read(fd, eui, 8);
-    if(rc < 0)
+    if(rc < 8)
         return -1;
     close(fd);
 
